@@ -46,6 +46,7 @@
 #include "index.h"
 #include "message.h"
 #include "oid.h"
+#include "pkcs11i.h"
 #include "pkcs11x.h"
 #include "utf8.h"
 #include "x509.h"
@@ -120,16 +121,16 @@ lookup_extension (p11_builder *builder,
 	node_asn *node;
 
 	CK_ATTRIBUTE match[] = {
-		{ CKA_X_PUBLIC_KEY_INFO, },
+		{ CKA_PUBLIC_KEY_INFO, },
 		{ CKA_OBJECT_ID, (void *)oid, p11_oid_length (oid) },
 		{ CKA_CLASS, &klass, sizeof (klass) },
 		{ CKA_INVALID },
 	};
 
 	if (public_key == NULL || public_key->type == CKA_INVALID)
-		public_key = p11_attrs_find_valid (cert, CKA_X_PUBLIC_KEY_INFO);
+		public_key = p11_attrs_find_valid (cert, CKA_PUBLIC_KEY_INFO);
 
-	/* Look for a stapled certificate extension */
+	/* Look for an attached certificate extension */
 	if (public_key != NULL) {
 		memcpy (match, public_key, sizeof (CK_ATTRIBUTE));
 		obj = p11_index_find (index, match, -1);
@@ -591,7 +592,7 @@ calc_certificate_category (p11_builder *builder,
 		/*
 		 * If there is no basic constraints extension, and the CA version is
 		 * v1, and is self-signed, then we assume this is a certificate authority.
-		 * So we add a BasicConstraints stapled certificate extension
+		 * So we add a BasicConstraints attached certificate extension
 		 */
 		is_ca = 1;
 
@@ -651,7 +652,7 @@ certificate_value_attrs (CK_ATTRIBUTE *attrs,
 		end_date.ulValueLen = 0;
 
 	if (calc_element (node, der, der_len, "tbsCertificate.subjectPublicKeyInfo", public_key))
-		public_key->type = CKA_X_PUBLIC_KEY_INFO;
+		public_key->type = CKA_PUBLIC_KEY_INFO;
 	else
 		public_key->type = CKA_INVALID;
 	calc_element (node, der, der_len, "tbsCertificate.issuer.rdnSequence", &issuer);
@@ -783,7 +784,7 @@ const static builder_schema certificate_schema = {
 	  { CKA_HASH_OF_SUBJECT_PUBLIC_KEY, CREATE },
 	  { CKA_HASH_OF_ISSUER_PUBLIC_KEY, CREATE },
 	  { CKA_JAVA_MIDP_SECURITY_DOMAIN, CREATE, type_ulong },
-	  { CKA_X_PUBLIC_KEY_INFO, WANT, type_der_key },
+	  { CKA_PUBLIC_KEY_INFO, WANT, type_der_key },
 	  { CKA_INVALID },
 	}, certificate_populate, certificate_validate,
 };
@@ -823,7 +824,7 @@ const static builder_schema extension_schema = {
 	NORMAL_BUILD,
 	{ COMMON_ATTRS,
 	  { CKA_VALUE, REQUIRE | CREATE, type_der_ext },
-	  { CKA_X_PUBLIC_KEY_INFO, REQUIRE | CREATE, type_der_key },
+	  { CKA_PUBLIC_KEY_INFO, REQUIRE | CREATE, type_der_key },
 	  { CKA_OBJECT_ID, CREATE | WANT, type_der_oid },
 	  { CKA_ID, CREATE | MODIFY },
 	  { CKA_INVALID },
@@ -1718,7 +1719,7 @@ replace_compat_for_ext (p11_builder *builder,
 	CK_ATTRIBUTE *public_key;
 	int i;
 
-	public_key = p11_attrs_find_valid (attrs, CKA_X_PUBLIC_KEY_INFO);
+	public_key = p11_attrs_find_valid (attrs, CKA_PUBLIC_KEY_INFO);
 	if (public_key == NULL)
 		return;
 
@@ -1749,7 +1750,7 @@ update_related_category (p11_builder *builder,
 		{ CKA_INVALID, },
 	};
 
-	public_key = p11_attrs_find_valid (attrs, CKA_X_PUBLIC_KEY_INFO);
+	public_key = p11_attrs_find_valid (attrs, CKA_PUBLIC_KEY_INFO);
 	if (public_key == NULL)
 		return;
 
